# -*- coding: utf-8 -*-

"""
/***************************************************************************
 processing
                                 A QGIS plugin
 description
                              -------------------
        begin                : 2016-12-03
        copyright            : (C) 2016 by Nico
        email                : nico@nico
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
"""

__author__ = 'Nico'
__date__ = '2016-12-03'
__copyright__ = '(C) 2016 by Nico'

# This will get replaced with a git SHA1 when you do a git archive

__revision__ = '$Format:%H$'
from PyQt4.QtGui import QIcon
from processing.core.AlgorithmProvider import AlgorithmProvider
from processing.core.ProcessingConfig import Setting, ProcessingConfig
#from moduleName_algorithm import classNameAlgorithm
from algorithms.medianFilter import medianFilterAlgorithm
from algorithms.closingFilter import closingFilterAlgorithm
from algorithms.train import trainAlgorithm
from algorithms.classify import classifyAlgorithm
from algorithms.sieveArea import sieveAreaAlgorithm
#from algorithms.DTW import dtwAlgorithm
from algorithms.splitTrainValidation import splitTrainValidation
#from algorithms.historicalFilter import historicalFilterAlgorithm
#from algorithms.historicalPostClassification import historicalPostClassAlgorithm

class processingProvider(AlgorithmProvider):

    MY_DUMMY_SETTING = 'MY_DUMMY_SETTING'

    def __init__(self):
        AlgorithmProvider.__init__(self)

        # Deactivate provider by default
        self.activate = True

        # Load algorithms
        self.alglist = [medianFilterAlgorithm(),
                        closingFilterAlgorithm(),
                        trainAlgorithm(),
                        classifyAlgorithm(),
                        sieveAreaAlgorithm(),
                        splitTrainValidation()
                        ]
#                        dtwAlgorithm(),
        for alg in self.alglist:
            alg.provider = self
            
            

    def initializeSettings(self):
        """In this method we add settings needed to configure our
        provider.

        Do not forget to call the parent method, since it takes care
        or automatically adding a setting for activating or
        deactivating the algorithms in the provider.
        """
        AlgorithmProvider.initializeSettings(self)
        ProcessingConfig.addSetting(Setting('dzetsaka algorithms',
            processingProvider.MY_DUMMY_SETTING,
            'Example setting', 'Default value'))

    def unload(self):
        """Setting should be removed here, so they do not appear anymore
        when the plugin is unloaded.
        """
        AlgorithmProvider.unload(self)
        ProcessingConfig.removeSetting(
            processingProvider.MY_DUMMY_SETTING)

    def getName(self):
        """This is the name that will appear on the toolbox group.

        It is also used to create the command line name of all the
        algorithms from this provider.
        """
        return 'dzetsaka'

    def getDescription(self):
        """This is the provired full name.
        """
        return 'dzetsaka'

    def getIcon(self):
        """We return the default icon.
        """
        return QIcon(":/plugins/dzetsaka/img/icon.png")

    def _loadAlgorithms(self):
        """Here we fill the list of algorithms in self.algs.

        This method is called whenever the list of algorithms should
        be updated. If the list of algorithms can change (for instance,
        if it contains algorithms from user-defined scripts and a new
        script might have been added), you should create the list again
        here.

        In this case, since the list is always the same, we assign from
        the pre-made list. This assignment has to be done in this method
        even if the list does not change, since the self.algs list is
        cleared before calling this method.
        """
        self.algs = self.alglist
